package me.yeojoy.simplechat;

import me.yeojoy.simplechat.R;

import me.yeojoy.simplechat.adapter.ChatCursorAdapter;
import me.yeojoy.simplechat.data.ChattingData;
import me.yeojoy.simplechat.db.ChatDBHelper;
import me.yeojoy.simplechat.db.ChatDatabase;

import android.app.Activity;
import android.content.ContentValues;
import android.database.Cursor;
import android.database.DataSetObserver;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.CursorAdapter;
import android.widget.EditText;
import android.widget.ListView;

/**
 * 기본 CursorAdapter를 사용해서 구현
 * @author yeojoy
 *
 */

public class ChatActivity3 extends Activity {

    private static final String TEMP = "..";
    
    private EditText mEtInput;
    
    private Cursor mChatCursor;
    private ChatCursorAdapter mChatCursorAdapter;
    
    private ChatDBHelper mDBHelper;
    
    private ListView mLvChatting;
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.chat);
        
        mLvChatting = (ListView) findViewById(R.id.lv_chat);
        
        mDBHelper = new ChatDBHelper(this);
        
        mEtInput = (EditText) findViewById(R.id.et_input);
        
        SQLiteDatabase db = mDBHelper.getWritableDatabase();
        mChatCursor = getCursor(db);
        mChatCursorAdapter = new ChatCursorAdapter(this, mChatCursor, CursorAdapter.FLAG_REGISTER_CONTENT_OBSERVER); 
        mLvChatting.setAdapter(mChatCursorAdapter);
        db.close();
        
        mChatCursor.registerDataSetObserver(new DataSetObserver() {
            @Override
            public void onChanged() {
                super.onChanged();
//                SQLiteDatabase db = mDBHelper.getWritableDatabase();
//                mChatCursor = getCursor(db);
//                db.close();
                
                mChatCursorAdapter.changeCursor(mChatCursor);
                
                mChatCursorAdapter.notifyDataSetChanged();
                mLvChatting.invalidate();
                scrollMyListViewToBottom();
            }
        });
    }

    @Override
    protected void onResume() {
        super.onResume();
        
    }
    
    @Override
    protected void onPause() {
        super.onPause();
        
    }
    
    @Override
    protected void onDestroy() {
        // here
        mChatCursor.close();
        mDBHelper.close();
        super.onDestroy();
    }
    
    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.btn_send:
                sendChattingMessage();
                mEtInput.setText("");
                break;
        }
    }

    private void sendChattingMessage() {
        ChattingData chatting = new ChattingData();
        String message = mEtInput.getText().toString();
        
        if (!message.startsWith(TEMP)) {
            chatting.setComment(message);
            chatting.setImageUrl(null);
            chatting.setMine(true);
            chatting.setName("ME");
            chatting.setChatType(ChatCursorAdapter.CHAT_ROOM_TYPE_ME);
        } else {
            message = message.substring(TEMP.length());
            chatting.setComment(message);
            chatting.setImageUrl(null);
            chatting.setMine(false);
            chatting.setName("YOU");
            chatting.setChatType(ChatCursorAdapter.CHAT_ROOM_TYPE_YOU);
        }

        insertMessage(chatting);
    }
    
    private void scrollMyListViewToBottom() {
        mLvChatting.post(new Runnable() {
            @Override
            public void run() {
                // Select the last row so it will scroll into view...
                mLvChatting.setSelection(mChatCursorAdapter.getCount());
                Log.d("yeojoy", "ListView Position >>> " + (mChatCursorAdapter.getCount() - 1));
            }
        });
    }
    
    private Cursor getCursor(SQLiteDatabase db) {
        Cursor cursor = db.query(ChatDatabase.TABLE_NAME, 
                null, 
                null, 
                null, 
                null, 
                null, 
                null);
        return cursor;
    }
    
    private void insertMessage(ChattingData chattingData) {
        SQLiteDatabase db = mDBHelper.getWritableDatabase();
        ContentValues cv = new ContentValues();
        cv.put(ChatDatabase.IS_MINE, chattingData.getChatType());
        cv.put(ChatDatabase.USER_NAME, chattingData.getName());
        cv.put(ChatDatabase.USER_COMMENTS, chattingData.getComment());
        db.insert(ChatDatabase.TABLE_NAME, null, cv);
        db.close();
      
    }
}
