package me.yeojoy.simplechat;

import me.yeojoy.simplechat.R;

import me.yeojoy.simplechat.adapter.ChatCursorAdapter;
import me.yeojoy.simplechat.data.ChattingData;
import me.yeojoy.simplechat.db.ChatDBHelper;
import me.yeojoy.simplechat.db.ChatDatabase;

import android.app.Activity;
import android.app.LoaderManager;
import android.content.ContentValues;
import android.content.CursorLoader;
import android.content.Loader;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.CursorAdapter;
import android.widget.EditText;
import android.widget.ListView;

/**
 * CursorLoader를 사용해서 구현
 * @author yeojoy
 *
 */

public class ChatActivity4 extends Activity implements LoaderManager.LoaderCallbacks<Cursor> {

    private static final String TEMP = "..";
    
    private Cursor mChatCursor;
    private ChatCursorAdapter mChatCursorAdapter;
    
    private ChatDBHelper mDBHelper;
    
    private ListView mLvChatting;
    
    private EditText mEtInput;
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.chat);

        mLvChatting = (ListView) findViewById(R.id.lv_chat);
        
        mDBHelper = new ChatDBHelper(this);
        
        mEtInput = (EditText) findViewById(R.id.et_input);
        
//        mCursorLoader = new CursorLoader(this, ChatDatabase.CONTENT_URI, null, null, null, null);
        
        getLoaderManager().initLoader(0, null, this);
        
        mChatCursorAdapter = new ChatCursorAdapter(this, mChatCursor, CursorAdapter.FLAG_REGISTER_CONTENT_OBSERVER); 
        mLvChatting.setAdapter(mChatCursorAdapter);
        
        scrollMyListViewToBottom();
    }

    @Override
    protected void onResume() {
        super.onResume();
        
    }
    
    @Override
    protected void onPause() {
        super.onPause();
        
    }
    
    @Override
    protected void onDestroy() {
        // here
        if (mChatCursor != null)
            mChatCursor.close();
        mDBHelper.close();
        super.onDestroy();
    }
    
    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.btn_send:
                sendChattingMessage();
                mEtInput.setText("");
                break;
        }
    }

    private void sendChattingMessage() {
        ChattingData chatting = new ChattingData();
        String message = mEtInput.getText().toString();
        
        if (!message.startsWith(TEMP)) {
            chatting.setComment(message);
            chatting.setImageUrl(null);
            chatting.setMine(true);
            chatting.setName("ME");
            chatting.setChatType(ChatCursorAdapter.CHAT_ROOM_TYPE_ME);
        } else {
            message = message.substring(TEMP.length());
            chatting.setComment(message);
            chatting.setImageUrl(null);
            chatting.setMine(false);
            chatting.setName("YOU");
            chatting.setChatType(ChatCursorAdapter.CHAT_ROOM_TYPE_YOU);
        }

        insertMessage(chatting);
    }
    
    private void scrollMyListViewToBottom() {
        mLvChatting.post(new Runnable() {
            @Override
            public void run() {
                // Select the last row so it will scroll into view...
                mLvChatting.setSelection(mChatCursorAdapter.getCount());
                Log.d("yeojoy", "ListView Position >>> " + (mChatCursorAdapter.getCount()));
            }
        });
    }
    
    private void insertMessage(ChattingData chattingData) {
        SQLiteDatabase db = mDBHelper.getWritableDatabase();
        ContentValues cv = new ContentValues();
        cv.put(ChatDatabase.IS_MINE, chattingData.getChatType());
        cv.put(ChatDatabase.USER_NAME, chattingData.getName());
        cv.put(ChatDatabase.USER_COMMENTS, chattingData.getComment());
        db.insert(ChatDatabase.TABLE_NAME, null, cv);
        db.close();
     
        // requery개념으로 알아들으면 될 듯합니다요잉!
        // DB에 insert하고나서 
        getLoaderManager().restartLoader(0, null, this);
        scrollMyListViewToBottom();
    }

    // Called when a new Loader needs to be created
    @Override
    public Loader<Cursor> onCreateLoader(int id, Bundle args) {
        // Now create and return a CursorLoader that will take care of
        // creating a Cursor for the data being displayed.
        
        // This is called when a new Loader needs to be created.  This
        // sample only has one Loader, so we don't care about the ID.
        // First, pick the base URI to use depending on whether we are
        // currently filtering.
        
        ///////////////////////
        //
        // Sample Source
        //
        /*
        Uri baseUri;
        if (mCurFilter != null) {
            baseUri = Uri.withAppendedPath(Contacts.CONTENT_FILTER_URI,
                    Uri.encode(mCurFilter));
        } else {
            baseUri = Contacts.CONTENT_URI;
        }

        // Now create and return a CursorLoader that will take care of
        // creating a Cursor for the data being displayed.
        String select = "((" + Contacts.DISPLAY_NAME + " NOTNULL) AND ("
                + Contacts.HAS_PHONE_NUMBER + "=1) AND ("
                + Contacts.DISPLAY_NAME + " != '' ))";
        return new CursorLoader(getActivity(), baseUri,
                CONTACTS_SUMMARY_PROJECTION, select, null,
        
        */
        //
        //
        ///////////////////////
        
        return new CursorLoader(this, ChatDatabase.CONTENT_URI, null, null, null, null);
    }
    
    // Called when a previously created loader has finished loading
    @Override
    public void onLoadFinished(Loader<Cursor> loader, Cursor cursor) {
        // Swap the new cursor in.  (The framework will take care of closing the
        // old cursor once we return.) 
        mChatCursorAdapter.swapCursor(cursor);
    }

    // Called when a previously created loader is reset, making the data unavailable
    @Override
    public void onLoaderReset(Loader<Cursor> loader) {
        // This is called when the last Cursor provided to onLoadFinished()
        // above is about to be closed.  We need to make sure we are no
        // longer using it.
        mChatCursorAdapter.swapCursor(null);
    }
}
