package me.yeojoy.simplechat;

import me.yeojoy.simplechat.R;

import me.yeojoy.simplechat.adapter.ChatCursorAdapter;
import me.yeojoy.simplechat.data.ChattingData;
import me.yeojoy.simplechat.db.ChatDatabase;

import android.app.Activity;
import android.content.ContentResolver;
import android.content.ContentValues;
import android.database.ContentObserver;
import android.database.Cursor;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.View;
import android.widget.CursorAdapter;
import android.widget.EditText;
import android.widget.ListView;

public class ChatActivity5 extends Activity {

    private static final String TEMP = "..";
    
    private EditText mEtInput;
    
    private Cursor mChatCursor;
    private ChatCursorAdapter mChatCursorAdapter;
    
    private ContentResolver mContentResolver;
    private ChatContentObserver mContentObserver;
    
    private ListView mLvChatting;
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.chat);
        
        mLvChatting = (ListView) findViewById(R.id.lv_chat);
        mContentResolver = getContentResolver();
        
        mEtInput = (EditText) findViewById(R.id.et_input);
        
        mChatCursor = mContentResolver.query(ChatDatabase.CONTENT_URI, null, null, null, null);
        
        mChatCursorAdapter = new ChatCursorAdapter(this, mChatCursor, CursorAdapter.FLAG_REGISTER_CONTENT_OBSERVER); 
        mLvChatting.setAdapter(mChatCursorAdapter);
        
        // content observer 등록
        mContentObserver = new ChatContentObserver(mHandler);
        mContentResolver.registerContentObserver(ChatDatabase.CONTENT_URI, true, mContentObserver);
        Log.d("yeojoy", "onCreate in ChatActivity5");
    } // end of onCreate method

    @Override
    protected void onResume() {
        super.onResume();
        scrollMyListViewToBottom();
    }
    
    @Override
    protected void onPause() {
        super.onPause();
        
    }
    
    @Override
    protected void onDestroy() {
        // here
        mChatCursor.close();
        super.onDestroy();
    }
    
    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.btn_send:
                sendChattingMessage();
                mEtInput.setText("");
                Log.d("yeojoy", "onClick in ChatActivity5");
                break;
        }
    }

    private void sendChattingMessage() {
        ChattingData chatting = new ChattingData();
        String message = mEtInput.getText().toString();
        Log.d("yeojoy", "sendChattingMessage in ChatActivity5");
        
        if (message.startsWith(TEMP)) {
            // 너
            message = message.substring(TEMP.length());
            chatting.setComment(message);
            chatting.setImageUrl(null);
            chatting.setName("YOU");
            chatting.setChatType(ChatCursorAdapter.CHAT_ROOM_TYPE_YOU);
            Log.d("yeojoy", "send your ChattingMessage in ChatActivity5");
        } else {
            // 나
            chatting.setComment(message);
            chatting.setImageUrl(null);
            chatting.setName("ME");
            chatting.setChatType(ChatCursorAdapter.CHAT_ROOM_TYPE_ME);
            Log.d("yeojoy", "send my ChattingMessage in ChatActivity5");
        }

        insertMessage(chatting);
    }
    
    private void scrollMyListViewToBottom() {
        mLvChatting.post(new Runnable() {
            @Override
            public void run() {
                // Select the last row so it will scroll into view...
                mLvChatting.setSelection(mChatCursorAdapter.getCount());
            }
        });
    }
    
    private void insertMessage(ChattingData chattingData) {
        ContentValues cv = new ContentValues();
        cv.put(ChatDatabase.USER_NAME, chattingData.getName());
        cv.put(ChatDatabase.USER_COMMENTS, chattingData.getComment());
        cv.put(ChatDatabase.IS_MINE, chattingData.getChatType());
        mContentResolver.insert(ChatDatabase.CONTENT_URI, cv);
        
        Log.d("yeojoy", "insertMessage in ChatActivity5");
    } // end of insertMessage method
    
    class ChatContentObserver extends ContentObserver {
        
        private Handler innerHandler;
        
        public ChatContentObserver(Handler handler) {
            super(handler);
            innerHandler = handler;
            Log.d("yeojoy", "Construntor in ChatContentObserver");
        }
        
        @Override
        public void onChange(boolean selfChange) {
            super.onChange(selfChange);
            // requery 해준다.
            mChatCursor = mContentResolver.query(ChatDatabase.CONTENT_URI, null, null, null, null);
            innerHandler.sendEmptyMessage(0);
            Log.d("yeojoy", "onChange in ChatContentObserver");
        }
    } // end of ChatContentObserver class
    
    private Handler mHandler = new Handler() {
        @Override
        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            switch (msg.what) {
                case 0:        
                    Log.d("yeojoy", "handleMessage in Handler");
                    mChatCursorAdapter.changeCursor(mChatCursor);
                    scrollMyListViewToBottom();
                    break;
            }
        }
    }; // end of Handler
}
