package me.yeojoy.simplechat.adapter;

import me.yeojoy.simplechat.R;

import me.yeojoy.simplechat.data.ChattingData;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import java.util.List;

public class ChatBaseAdapter extends BaseAdapter {

    public static final int CHAT_ROOM_TYPE_YOU  = 0;
    public static final int CHAT_ROOM_TYPE_ME   = 1;
    
    private Context mContext;
    private LayoutInflater mInflater;
    
    private List<ChattingData> mListChattingData;
    private int chatRoomType;
    
    public ChatBaseAdapter(Context context, List<ChattingData> listChattingData) {
        mContext = context;
        mListChattingData = listChattingData;
        mInflater = (LayoutInflater) mContext.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
    }
    
    @Override
    public int getCount() {

        return mListChattingData.size();
    }

    @Override
    public Object getItem(int position) {
        return mListChattingData.get(position);
    }

    @Override
    public long getItemId(int position) {

        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        
        ViewHolder viewHolder = new ViewHolder();
        
        if (convertView == null) {
            switch (getItemViewType(position)) {
                case CHAT_ROOM_TYPE_ME:
                    
                    convertView = mInflater.inflate(R.layout.my_side, null);
                    viewHolder.myTalk = (TextView) convertView.findViewById(R.id.tv_my_talk);
//                    viewHolder.myReadFlag = (TextView) convertView.findViewById(R.id.tv_your_flag_for_read);
//                    viewHolder.myReadTime = (TextView) convertView.findViewById(R.id.tv_my_read_time);
                    
                    break;
                    
                case CHAT_ROOM_TYPE_YOU:
                    convertView = mInflater.inflate(R.layout.your_side, null);
                    viewHolder.yourImage = (ImageView) convertView.findViewById(R.id.iv_your_profile_image);
                    viewHolder.yourName = (TextView) convertView.findViewById(R.id.tv_your_name);
                    viewHolder.yourTalk = (TextView) convertView.findViewById(R.id.tv_your_talk);
//                    viewHolder.yourReadFlag = (TextView) convertView.findViewById(R.id.tv_your_flag_for_read);
//                    viewHolder.yourReadTime = (TextView) convertView.findViewById(R.id.tv_your_read_time);
                    
                    break;
            }
            convertView.setTag(viewHolder);
        } else {
            viewHolder = (ViewHolder) convertView.getTag();
        }
        
        setDataOnView(viewHolder, mListChattingData.get(position), position);
        
        return convertView;
    }
    
    
    @Override
    public int getViewTypeCount() {
        return 2;
    }
    
    @Override
    public int getItemViewType(int position) {
        if (mListChattingData.get(position).isMine())
            return CHAT_ROOM_TYPE_ME;
        else
            return CHAT_ROOM_TYPE_YOU;
    }
    
    private void setDataOnView(ViewHolder holder, ChattingData data, int position) {
        switch (getItemViewType(position)) {
            case CHAT_ROOM_TYPE_ME:
                holder.myTalk.setText(data.getComment());
                // TODO 시간, 플래그
                break;
                
            case CHAT_ROOM_TYPE_YOU:
                holder.yourTalk.setText(data.getComment());
                
                break;
        }
    }
    
    private class ViewHolder {
        // My Chat
        public TextView myTalk;
//        public TextView myReadFlag;
//        public TextView myReadTime;
        
        // Your Chat
        public ImageView yourImage;
        public TextView yourName;
        public TextView yourTalk;
//        public TextView yourReadFlag;
//        public TextView yourReadTime;
    }
}
