package me.yeojoy.simplechat.db;

import android.content.ContentProvider;
import android.content.ContentUris;
import android.content.ContentValues;
import android.content.UriMatcher;
import android.database.ContentObserver;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.net.Uri;
import android.util.Log;

public class ChatContentProvider extends ContentProvider {

    public static final int ALL_RECORD = 100001;
    
    private SQLiteDatabase mDB;
    
    static final UriMatcher Matcher;
    static {
        Matcher = new UriMatcher(UriMatcher.NO_MATCH);
        Matcher.addURI(ChatDatabase.AUTHORITY, ChatDatabase.PATH, ALL_RECORD);
    }
    
    private ContentObserver mContentObserver;
    
    @Override
    public boolean onCreate() {
        ChatDBHelper helper = new ChatDBHelper(getContext());
        mDB = helper.getWritableDatabase();
        Log.d("yeojoy", "onCreate in CP");
        return (mDB != null);
    }
    
    @Override
    public int delete(Uri uri, String selection, String[] selectionArgs) {
        return 0;
    }

    @Override
    public String getType(Uri uri) {
        
        return null;
    }

    @Override
    public Uri insert(Uri uri, ContentValues values) {
        long row = mDB.insert(ChatDatabase.TABLE_NAME, null, values);
        Log.d("yeojoy", "insert in CP");
        if (row > 0) {
            Uri notiUri = ContentUris.withAppendedId(ChatDatabase.CONTENT_URI, row);
            getContext().getContentResolver().notifyChange(notiUri, mContentObserver);
            Log.d("yeojoy", "insert success in CP");
            return notiUri;
        }
        return null;
    }

    @Override
    public Cursor query(Uri uri, String[] projection, String selection, String[] selectionArgs,
            String sortOrder) {
        int match = Matcher.match(uri);
        String sql = "SELECT * FROM " + ChatDatabase.TABLE_NAME;
        
        Log.d("yeojoy", "query in CP");
        if (match == ALL_RECORD) {
            // URI에 대한 게 많을 경우 이렇게 처리한다.
        }
        
        return mDB.rawQuery(sql, null);
    }

    @Override
    public int update(Uri uri, ContentValues values, String selection, String[] selectionArgs) {
        int count = 0;
        
        if ((Matcher.match(uri)) == ALL_RECORD) {
            count = mDB.update(ChatDatabase.TABLE_NAME, values, selection, selectionArgs);
        }
        Log.d("yeojoy", "update " + count + " in CP");
        getContext().getContentResolver().notifyChange(uri, mContentObserver);
        
        return count;
    }

    public void setContentObserver(ContentObserver co) {
        mContentObserver = co;
        Log.d("yeojoy", "setContentObserver in CP");
    }
}
